@@ -1,7 +1,11 @@
 package Date::Age;
 
+use 5.010;
+
 use strict;
 use warnings;
+
+use Carp qw(carp croak);
 use Exporter 'import';
 use Time::Local qw(timelocal);
 
@@ -13,11 +17,11 @@ Date::Age - Return an age or age range from date(s)
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -37,12 +41,24 @@ It works even with partial dates.
 =cut
 
 sub describe {
+	if($_[0] eq __PACKAGE__) {
+		shift;
+	}
+
+	croak('Usage: ', __PACKAGE__, '::describe($dob, $ref)') unless(scalar(@_) == 2);
+
 	my ($dob, $ref) = @_;
 	my $info = details($dob, $ref);
 	return $info->{range};
 }
 
 sub details {
+	if($_[0] eq __PACKAGE__) {
+		shift;
+	}
+
+	croak('Usage: ', __PACKAGE__, '::details($dob, $ref)') unless(scalar(@_) == 2);
+
 	my ($dob, $ref) = @_;
 
 	my ($dob_early, $dob_late) = _parse_date_range($dob);
@@ -63,7 +79,8 @@ sub details {
 }
 
 sub _now_string {
-	return localtime->ymd();
+	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime();
+	return sprintf('%04d-%02d-%02d', $year + 1900, $mon + 1, $mday);
 }
 
 sub _calc_age_localtime {
